| Safe Haskell | Safe |
|---|---|
| Language | Haskell2010 |
System.Directory.Watchman.SyncTimeout
- class HasSyncTimeoutOption a where
- syncTimeout :: HasSyncTimeoutOption a => Int -> a -> a
- syncOff :: HasSyncTimeoutOption a => a -> a
Documentation
class HasSyncTimeoutOption a where Source #
Minimal complete definition
Methods
setSyncTimeout :: Maybe Int -> a -> a Source #
Arguments
| :: HasSyncTimeoutOption a | |
| => Int | Time to wait in milliseconds |
| -> a -> a |
Set the timeout value for query synchronization. If the timeout passes, the command will return with an error.
syncOff :: HasSyncTimeoutOption a => a -> a Source #
Disable query synchronization for this command.
The query will be evaluated over the present view of the tree, which may lag behind the present state of the filesystem.